indicatortools.StemTremolo
==========================

.. abjad-lineage:: abjad.tools.indicatortools.StemTremolo.StemTremolo

.. autoclass:: abjad.tools.indicatortools.StemTremolo.StemTremolo

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.indicatortools.StemTremolo.StemTremolo.tremolo_flags
      ~abjad.tools.indicatortools.StemTremolo.StemTremolo.__copy__
      ~abjad.tools.indicatortools.StemTremolo.StemTremolo.__eq__
      ~abjad.tools.indicatortools.StemTremolo.StemTremolo.__format__
      ~abjad.tools.indicatortools.StemTremolo.StemTremolo.__ne__
      ~abjad.tools.indicatortools.StemTremolo.StemTremolo.__repr__
      ~abjad.tools.indicatortools.StemTremolo.StemTremolo.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.indicatortools.StemTremolo.StemTremolo.tremolo_flags
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.indicatortools.StemTremolo.StemTremolo.__copy__
   :noindex:

.. automethod:: abjad.tools.indicatortools.StemTremolo.StemTremolo.__eq__
   :noindex:

.. automethod:: abjad.tools.indicatortools.StemTremolo.StemTremolo.__format__
   :noindex:

.. automethod:: abjad.tools.indicatortools.StemTremolo.StemTremolo.__ne__
   :noindex:

.. automethod:: abjad.tools.indicatortools.StemTremolo.StemTremolo.__repr__
   :noindex:

.. automethod:: abjad.tools.indicatortools.StemTremolo.StemTremolo.__str__
   :noindex:
